"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const ramda_1 = require("ramda");
async function default_1(systemSettings, presentationPath, componentsProps, options) {
    const blocksPath = ramda_1.pathOr('', ['path', 'blocks'], systemSettings);
    const blockManifestFilePath = ramda_1.pathOr('', ['path', 'blocksManifest'], systemSettings);
    const componentsFilename = ramda_1.pathOr('', ['path', 'componentsFilename'], systemSettings);
    const componentsDirectory = ramda_1.pathOr('', ['path', 'localComponents'], systemSettings);
    const blocksThemesFilename = ramda_1.pathOr('', ['path', 'blocksThemes'], systemSettings);
    const componentsThemesFilename = ramda_1.pathOr('', ['path', 'componentsThemes'], systemSettings);
    const masterTemplatePath = ramda_1.pathOr('', ['path', 'masterTemplatePath'], systemSettings);
    const layoutsPath = ramda_1.pathOr('', ['path', 'layouts'], systemSettings);
    const blockManifestResolvedPath = path_1.resolve(presentationPath, blockManifestFilePath);
    const componentsFullPath = path_1.join(componentsDirectory, componentsFilename);
    const componentManifestResolvedPath = path_1.resolve(presentationPath, componentsFullPath);
    const blocksThemesManifestResolvedPath = path_1.resolve(presentationPath, blocksThemesFilename);
    const componentsThemesManifestResolvedPath = path_1.resolve(presentationPath, componentsThemesFilename);
    const [blockManifestPath, componentManifestPath, blocksThemesPath, componentsThemesPath,] = await Promise.all([
        getResolvedPath(presentationPath, blockManifestFilePath, blockManifestResolvedPath, options, layoutsPath),
        getResolvedPath(presentationPath, componentsFullPath, componentManifestResolvedPath, options, layoutsPath),
        getResolvedPath(presentationPath, blocksThemesFilename, blocksThemesManifestResolvedPath, options, layoutsPath),
        getResolvedPath(presentationPath, componentsThemesFilename, componentsThemesManifestResolvedPath, options, layoutsPath),
    ]);
    return [
        {
            include: [
                require.resolve('../assets/compound-manifest.js'),
            ],
            use: [
                {
                    loader: 'manifest-loader',
                    options: {
                        blocksPath,
                        presentationPath,
                        componentsProps,
                        blockManifestPath,
                        componentManifestPath,
                        blocksThemesPath,
                        componentsThemesPath,
                        masterTemplatePath,
                        currentTheme: options.currentTheme
                    },
                },
            ],
        },
    ];
}
exports.default = default_1;
async function getResolvedPath(presentationPath, filename, resolvedPath, options, layoutsPath) {
    if (options.layout) {
        const manifestResolvedPathLayout = path_1.resolve(presentationPath, layoutsPath, options.layout, filename);
        if (await fs_extra_1.pathExists(manifestResolvedPathLayout)) {
            return manifestResolvedPathLayout;
        }
    }
    return await fs_extra_1.pathExists(resolvedPath) ? resolvedPath : '';
}
//# sourceMappingURL=get-manifest-loaders.js.map